# Retrieving Fact Sheets (GraphQL)
### On this page
  * [Retrieving a Fact Sheet by ID](https://help.sap.com/docs/leanix/ea/retrieving-fact-sheets#retrieving-a-fact-sheet-by-id)
  * [Retrieving All Fact Sheets](https://help.sap.com/docs/leanix/ea/retrieving-fact-sheets#retrieving-all-fact-sheets)
  * [Retrieving Custom Fact Sheet Attributes](https://help.sap.com/docs/leanix/ea/retrieving-fact-sheets#retrieving-custom-fact-sheet-attributes)
  * [Retrieving Related Fact Sheets](https://help.sap.com/docs/leanix/ea/retrieving-fact-sheets#retrieving-related-fact-sheets)


Example queries for retrieving fact sheets through the GraphQL API.
In the example queries, we only retrieve basic fact sheet attributes, such as id, name, or type. Modify the queries to retrieve the data you need.
